==> astro-google-analytics-1.0.1.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## 1.0.1 (2022-10-17)


### Bug Fixes

* remove package prefix, simplify import method ([73bd31b](https://github.com/JulianCataldo/web-garden/commit/73bd31bf1f501624036a74a3f19c5bf83cc9c0a4))



## [0.11.7](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.6...@julian_cataldo/astro-analytics@0.11.7) (2022-10-13)


### Bug Fixes

* add missing props importer ([68e68e9](https://github.com/JulianCataldo/web-garden/commit/68e68e94e3c4a97fbd1bd2782051c09e94c88301))



## [0.11.6](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.5...@julian_cataldo/astro-analytics@0.11.6) (2022-09-22)

**Note:** Version bump only for package @julian_cataldo/astro-analytics





## [0.11.5](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.4...@julian_cataldo/astro-analytics@0.11.5) (2022-08-20)

**Note:** Version bump only for package @julian_cataldo/astro-analytics





## [0.11.4](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.3...@julian_cataldo/astro-analytics@0.11.4) (2022-08-06)

**Note:** Version bump only for package @julian_cataldo/astro-analytics





## [0.11.3](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.2...@julian_cataldo/astro-analytics@0.11.3) (2022-07-26)


### Bug Fixes

* incorrect property id variable ([25bfd35](https://github.com/JulianCataldo/web-garden/commit/25bfd35c54878919e484b6ffbb8a767ea6d38592))



## [0.11.2](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.1...@julian_cataldo/astro-analytics@0.11.2) (2022-07-24)

**Note:** Version bump only for package @julian_cataldo/astro-analytics





## [0.11.1](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.0...@julian_cataldo/astro-analytics@0.11.1) (2022-07-18)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.0](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.4...@julian_cataldo/astro-analytics@0.11.0) (2022-06-28)

### Features

- better defaults properties ([cc55aec](https://github.com/JulianCataldo/web-garden/commit/cc55aecd0ea8051ab268c391cb5a28372d7ca896))

## [0.10.4](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.3...@julian_cataldo/astro-analytics@0.10.4) (2022-06-26)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.3](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.2...@julian_cataldo/astro-analytics@0.10.3) (2022-06-25)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.2](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.1...@julian_cataldo/astro-analytics@0.10.2) (2022-06-21)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.1](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.0...@julian_cataldo/astro-analytics@0.10.1) (2022-06-20)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## 0.10.0 (2022-06-19)

### Features

- init app analytics component ([f76c86e](https://github.com/JulianCataldo/web-garden/commit/f76c86ea2681851540e9815192bb669f4f0b7831))

==> astro-google-analytics-1.0.2.tgz: package/CHANGELOG.md <==
# Change Log

All notable changes to this project will be documented in this file.
See [Conventional Commits](https://conventionalcommits.org) for commit guidelines.

## [1.0.2](https://github.com/JulianCataldo/web-garden/compare/astro-google-analytics@1.0.1...astro-google-analytics@1.0.2) (2022-11-19)

**Note:** Version bump only for package astro-google-analytics

## 1.0.1 (2022-10-17)

### Bug Fixes

- remove package prefix, simplify import method ([73bd31b](https://github.com/JulianCataldo/web-garden/commit/73bd31bf1f501624036a74a3f19c5bf83cc9c0a4))

## [0.11.7](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.6...@julian_cataldo/astro-analytics@0.11.7) (2022-10-13)

### Bug Fixes

- add missing props importer ([68e68e9](https://github.com/JulianCataldo/web-garden/commit/68e68e94e3c4a97fbd1bd2782051c09e94c88301))

## [0.11.6](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.5...@julian_cataldo/astro-analytics@0.11.6) (2022-09-22)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.5](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.4...@julian_cataldo/astro-analytics@0.11.5) (2022-08-20)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.4](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.3...@julian_cataldo/astro-analytics@0.11.4) (2022-08-06)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.3](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.2...@julian_cataldo/astro-analytics@0.11.3) (2022-07-26)

### Bug Fixes

- incorrect property id variable ([25bfd35](https://github.com/JulianCataldo/web-garden/commit/25bfd35c54878919e484b6ffbb8a767ea6d38592))

## [0.11.2](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.1...@julian_cataldo/astro-analytics@0.11.2) (2022-07-24)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.1](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.11.0...@julian_cataldo/astro-analytics@0.11.1) (2022-07-18)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.11.0](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.4...@julian_cataldo/astro-analytics@0.11.0) (2022-06-28)

### Features

- better defaults properties ([cc55aec](https://github.com/JulianCataldo/web-garden/commit/cc55aecd0ea8051ab268c391cb5a28372d7ca896))

## [0.10.4](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.3...@julian_cataldo/astro-analytics@0.10.4) (2022-06-26)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.3](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.2...@julian_cataldo/astro-analytics@0.10.3) (2022-06-25)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.2](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.1...@julian_cataldo/astro-analytics@0.10.2) (2022-06-21)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## [0.10.1](https://github.com/JulianCataldo/web-garden/compare/@julian_cataldo/astro-analytics@0.10.0...@julian_cataldo/astro-analytics@0.10.1) (2022-06-20)

**Note:** Version bump only for package @julian_cataldo/astro-analytics

## 0.10.0 (2022-06-19)

### Features

- init app analytics component ([f76c86e](https://github.com/JulianCataldo/web-garden/commit/f76c86ea2681851540e9815192bb669f4f0b7831))
